@@ -4,8 +4,8 @@
 
 ;; Author: Eki Zhang <liuyinz95@gmail.com>
 ;; Maintainer: Eki Zhang <liuyinz95@gmail.com>
-;; Package-Version: 20250910.1021
-;; Package-Revision: 60ef63466d07
+;; Package-Version: 20251229.1550
+;; Package-Revision: 849c44b36594
 ;; Package-Requires: ((emacs "29.1") (inheritenv "0.2"))
 ;; Keywords: tools, processes
 ;; Homepage: https://github.com/eki3z/mise.el
@@ -204,7 +204,7 @@ command arguments to `mise'"
               (json-object-type 'hash-table))
     (unless (string-prefix-p "[" (string-trim output))
       (with-temp-buffer
-        (insert str)
+        (insert output)
         (goto-char (point-max))
         (when (re-search-backward "^\\[" nil t)
           (forward-line 0)  ; ensure at BOL
